Ff800AnalogInConfig

Struct Ff800AnalogInConfig 

pub struct Ff800AnalogInConfig {
    pub jacks: [Ff800AnalogInputJack; 3],
    pub line_level: FormerLineInNominalLevel,
    pub phantom_powering: [bool; 4],
    pub inst: Ff800InstConfig,
}
Configuration for analog inputs.

Fields

jacks: [Ff800AnalogInputJack; 3]

Whether to use rear jack instead of front jack for input 1, 7, and 8.

line_level: FormerLineInNominalLevel

The nominal level of audio signal for line input.

phantom_powering: [bool; 4]

Whether to deliver +48 V powering for mic 7, 8, 9, 10.

inst: Ff800InstConfig

The configurations for instrument input.