State of output volumes.
The value for volume is between 0x00000000 and 0x00010000 through 0x00000001 and 0x00080000 to represent the range from negative infinite to 6.00 dB through -90.30 dB and 0.00 dB.
Tuple Fields
0: Vec<i32>Trait Implementations
sourceimpl Clone for FormerOutputVolumeState
impl Clone for FormerOutputVolumeState
sourcefn clone(&self) -> FormerOutputVolumeState
fn clone(&self) -> FormerOutputVolumeState
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for FormerOutputVolumeState
impl Debug for FormerOutputVolumeState
sourceimpl Default for FormerOutputVolumeState
impl Default for FormerOutputVolumeState
sourcefn default() -> FormerOutputVolumeState
fn default() -> FormerOutputVolumeState
Returns the “default value” for a type. Read more
sourceimpl PartialEq<FormerOutputVolumeState> for FormerOutputVolumeState
impl PartialEq<FormerOutputVolumeState> for FormerOutputVolumeState
sourcefn eq(&self, other: &FormerOutputVolumeState) -> bool
fn eq(&self, other: &FormerOutputVolumeState) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &FormerOutputVolumeState) -> bool
fn ne(&self, other: &FormerOutputVolumeState) -> bool
This method tests for !=.
impl Eq for FormerOutputVolumeState
impl StructuralEq for FormerOutputVolumeState
impl StructuralPartialEq for FormerOutputVolumeState