pub struct FfLatterInputState {
    pub stereo_links: Vec<bool>,
    pub invert_phases: Vec<bool>,
    pub line_gains: Vec<i16>,
    pub line_levels: Vec<LatterInNominalLevel>,
    pub mic_powers: Vec<bool>,
    pub mic_insts: Vec<bool>,
}
State of inputs.

Fields

stereo_links: Vec<bool>

Whether to link each pair of left and right ports.

invert_phases: Vec<bool>

Whether to inverse the phase of analog, spdif, and adat inputs.

line_gains: Vec<i16>

The gain of analog line input. The value is between 0 and 120 to represent 0.00 dB and 12.00 dB.

line_levels: Vec<LatterInNominalLevel>

The nominal level of analog line input.

mic_powers: Vec<bool>

Whether to enable powering for mic input.

mic_insts: Vec<bool>

Whether to use mic input for instrument.