pub struct FfLatterOutputState {
    pub vols: Vec<i16>,
    pub stereo_balance: Vec<i16>,
    pub stereo_links: Vec<bool>,
    pub invert_phases: Vec<bool>,
    pub line_levels: Vec<LineOutNominalLevel>,
}
State of outputs.

Fields

vols: Vec<i16>

The level of volume. Each value is between -650 (0xfd76) and 60 (0x003c) to represent -65.00 dB and 6.00 dB.

stereo_balance: Vec<i16>

The balance between left and right. The value is between -100 (0xff9c) and 100 (0x0064).

stereo_links: Vec<bool>

Whether to link each pair of left and right ports.

invert_phases: Vec<bool>

Whether to inverse the phase of analog, spdif, and adat outputs.

line_levels: Vec<LineOutNominalLevel>

The nominal level of analog line output.